﻿' EXAMPLE - SQL06 for Visual Basic using ADO.NET
' When you run this example, two databases are created each with a table.
' Each table is populated with a few rows and finally the data read with
' a single query.
' 
' The following methods are illustrated:
'     Raima.Rdm.RdmConnection:
'         ChangeDatabase(string) Method
'         Close() Method
'         CreateCommand() Method
'         Open() Method
'         RdmConnection() Constructor
'     Raima.Rdm.RdmCommand:
'         CommandText Property
'         ExecuteNonQuery() Method
'         ExecuteReader() Method
'     Raima.Rdm.RdmDataReader:
'         Item[int] Property
'         Read() Method
' 
' They are fully document in http://docs.raima.com/rdm/.
' 
' For simplicity this example does not catch any thrown execptions
' but good programming practices would dictate that this occur in
' a full application.

' Raima.Rdm is the system module that contains the ADO.NET
' data provider for RDM
Imports Rdm = Raima.Rdm

Module SQL06
    Sub DropDatabase(conn As Rdm.RdmConnection, name As String)
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        ' Attempt to drop this database.  If the database does not already
        ' exist this will fail and we simply ignore the failure for this
        ' sample.
        Try
            cmd.CommandText = "DROP DATABASE " + name
            cmd.ExecuteNonQuery()
        Catch ex As Exception
        End Try

    End Sub

    Sub CreateThisDatabase(conn As Rdm.RdmConnection, name As String, cmds() As String)
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        cmd.CommandText = "CREATE DATABASE " + name
        cmd.ExecuteNonQuery()

        For Each c In cmds
            cmd.CommandText = c
            cmd.ExecuteNonQuery()
        Next

        cmd.CommandText = "COMMIT"
        cmd.ExecuteNonQuery()

        cmd.CommandText = "CLOSE " + name
        cmd.ExecuteNonQuery()
    End Sub

    Sub CreateDatabases(conn As Rdm.RdmConnection)
        ' Drop any existing copies of the databases.
        DropDatabase(conn, "SQL06_1")
        DropDatabase(conn, "SQL06_2")

        ' Attempt to create the databases
        Dim cmds(0) As String
        cmds(0) = "CREATE TABLE Table1 (id INTEGER PRIMARY KEY, str CHAR(30))"
        CreateThisDatabase(conn, "SQL06_1", cmds)

        cmds(0) = "CREATE TABLE Table2 (id INTEGER, str CHAR(30))"
        CreateThisDatabase(conn, "SQL06_2", cmds)
    End Sub

    Sub Main()
        ' Create the connection with a simple connection string
        Dim conn As Rdm.RdmConnection
        conn = New Rdm.RdmConnection("host=local;openmode=x")
        conn.Open()

        CreateDatabases(conn)

        ' Specify which databases to use
        conn.ChangeDatabase("SQL06_1;SQL06_2")

        ' Create a new command
        Dim cmd As Rdm.RdmCommand
        cmd = conn.CreateCommand()

        ' Insert one row into the table in the first database
        cmd.CommandText = "INSERT INTO Table1 VALUES 1, 'database1 1'"
        cmd.ExecuteNonQuery()

        ' Insert three rows into the table in the second database
        For ii = 1 To 3
            cmd.CommandText = "INSERT INTO Table2 VALUES 1, 'database2 " + Convert.ToString(ii) + "'"
            cmd.ExecuteNonQuery()
        Next

        ' Scan through the data, generating the result
        cmd.CommandText = "SELECT Table1.str, Table2.str FROM Table1, Table2 WHERE Table1.id = Table2.id"
        Dim reader As Rdm.RdmDataReader
        reader = cmd.ExecuteReader()

        While (reader.Read())
            Console.WriteLine(reader.Item(0) + " -- " + reader.Item(1))
        End While

        conn.Close()

        Console.WriteLine("Hit <Enter> to continue")
        Console.ReadLine()
    End Sub
End Module
